@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2008 Bertjan Broeksema <b.broeksema@kdemail.net>
+    Copyright (c) 2008 Bertjan Broeksema <broeksema@kde.org>
     Copyright (c) 2008 Volker Krause <vkrause@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
@@ -182,7 +182,7 @@ void SingleFileResourceBase::reloadFile()
 
   // if we have something loaded already, make sure we write that back in case
   // the settings changed
-  if ( !mCurrentUrl.isEmpty() )
+  if ( !mCurrentUrl.isEmpty() && !readOnly() )
     writeFile();
 
   readFile();
@@ -243,7 +243,7 @@ void SingleFileResourceBase::fileChanged( const QString & fileName )
 
 void SingleFileResourceBase::scheduleWrite()
 {
-  scheduleCustomTask(this, "writeFile", QVariant(), ResourceBase::AfterChangeReplay);
+  scheduleCustomTask(this, "writeFile", QVariant(true), ResourceBase::AfterChangeReplay);
 }
 
 void SingleFileResourceBase::slotDownloadJobResult( KJob *job )
